@@ -36,6 +36,7 @@
 
 #include "up-device-supply.h"
 #include "up-device-csr.h"
+#include "up-device-lg-unifying.h"
 #include "up-device-wup.h"
 #include "up-device-hid.h"
 #include "up-input.h"
@@ -133,7 +134,7 @@ up_backend_device_new (UpBackend *backend, GUdevDevice *native)
 		/* no valid TTY object */
 		device = NULL;
 
-	} else if (g_strcmp0 (subsys, "usb") == 0) {
+	} else if (g_strcmp0 (subsys, "usb") == 0 || g_strcmp0 (subsys, "usbmisc") == 0) {
 
 #ifdef HAVE_IDEVICE
 		/* see if this is an iDevice */
@@ -166,20 +167,27 @@ up_backend_device_new (UpBackend *backend, GUdevDevice *native)
 		/* check input device */
 		input = up_input_new ();
 		ret = up_input_coldplug (input, backend->priv->daemon, native);
-		if (!ret) {
+		if (ret) {
+			/* we now have a lid */
+			up_daemon_set_lid_is_present (backend->priv->daemon, TRUE);
+
+			/* not a power device */
+			up_device_list_insert (backend->priv->managed_devices, G_OBJECT (native), G_OBJECT (input));
+
+			/* no valid input object */
+			device = NULL;
+		} else {
 			g_object_unref (input);
-			goto out;
+
+			/* see if this is a Unifying mouse or keyboard */
+			device = UP_DEVICE (up_device_unifying_new ());
+			ret = up_device_coldplug (device, backend->priv->daemon, G_OBJECT (native));
+			if (!ret) {
+				g_object_unref (device);
+				/* no valid input object */
+				device = NULL;
+			}
 		}
-
-		/* we now have a lid */
-		up_daemon_set_lid_is_present (backend->priv->daemon, TRUE);
-
-		/* not a power device */
-		up_device_list_insert (backend->priv->managed_devices, G_OBJECT (native), G_OBJECT (input));
-
-		/* no valid input object */
-		device = NULL;
-
 	} else {
 		native_path = g_udev_device_get_sysfs_path (native);
 		g_warning ("native path %s (%s) ignoring", native_path, subsys);
@@ -320,7 +328,7 @@ up_backend_coldplug (UpBackend *backend, UpDaemon *daemon)
 	GList *l;
 	guint i;
 	gboolean ret;
-	const gchar *subsystems[] = {"power_supply", "usb", "tty", "input", NULL};
+	const gchar *subsystems[] = {"power_supply", "usb", "usbmisc", "tty", "input", NULL};
 
 	backend->priv->daemon = g_object_ref (daemon);
 	backend->priv->device_list = up_daemon_get_device_list (daemon);
@@ -603,10 +611,11 @@ gboolean
 up_backend_emits_resuming (UpBackend *backend)
 {
 #ifdef HAVE_SYSTEMD
-	return TRUE;
-#else
-	return FALSE;
+	if (sd_booted ())
+		return TRUE;
+	else
 #endif
+	return FALSE;
 }
 
 /**
